NLSL: symdef.f90 Source File

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

symdef.f90
Go to the documentation of this file.
1 c NLSL Version 1.9.0 beta 2/12/15
2 c----------------------------------------------------------------------
3 c =========================
4 c module SYMDEF
5 c =========================
6 c
7 c Definition of constants for enumerating symmetry types
8 c
9 c----------------------------------------------------------------------
10 c
11 module symdef
12 implicit none
13 c
14 integer, parameter :: cartesian=1, spherical=2, axial=3
15 c
16 end module symdef
symdef::axial
integer, parameter axial
Definition: symdef.f90:14
symdef::cartesian
integer, parameter cartesian
Definition: symdef.f90:14
symdef::spherical
integer, parameter spherical
Definition: symdef.f90:14
symdef
Definition: symdef.f90:11